@@ -409,55 +409,56 @@ impl Area{
 			}
 		}
 	}
+	/// Retorna o valor da área concedida em quilômetros quadrados
 	pub fn to_square_kilometers(&self) -> f64 {
 		if self.value > 1_000_000_000_000_000f64{
 			return self.value;
 		}
 		else {
 			if self.area_type == String::from("Square Micrometer"){
-				return self.value / 1_000_000.0;
+				return self.value / 1_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Millimeters"){
-				return self.value;
+				return self.value / 1_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Centimeters"){
-				return self.value * 100.0;
+				return self.value / 1_000_000_000_0.0;
 			}
 			else if self.area_type == String::from("Square Decimeters"){
-				return self.value * 1_000_0.0;
+				return self.value / 1_000_000_00.0;
 			}
 			else if self.area_type == String::from("Square Meters"){
-				return self.value * 1_000_000.0;
+				return self.value / 1_000_000.0;
 			}
 			else if self.area_type == String::from("Square Decameters"){
-				return self.value * 1_000_000_00.0;
+				return self.value / 1_000_0.0;
 			}
 			else if self.area_type == String::from("Square Hectometers"){
-				return self.value * 1_000_000_000_0.0;
+				return self.value / 100.0;
 			}
 			else if self.area_type == String::from("Square Kilometers"){
-				return self.value * 1_000_000_000_000.0;
+				return self.value;
 			}
 			else if self.area_type == String::from("Square Megameters"){
-				return self.value * 1_000_000_000_000_00.0;
+				return self.value * 1_000_000.0;
 			}
 			else if self.area_type == String::from("Square Gigameters"){
-				return self.value * 1_000_000_000_000_000_0.0;
+				return self.value * 1_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Terameters"){
 				return self.value * 1_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Miles"){
-				return self.value * (2.59 * 1_000_000_000_000.0);
+				return self.value * 2.59;
 			}
 			else if self.area_type == String::from("Square Yards"){
-				return self.value * 836_127.0;
+				return self.value / (1.196 * 1_000_000.0);
 			}
 			else if self.area_type == String::from("Square Feet"){
-				return self.value * 92_903.0;
+				return self.value / (1.076 * 1_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Inches"){
-				return self.value * 645.16;
+				return self.value / (1.55 * 1_000_000_000.0);
 			}
 			else{
 				println!("Invalid area type");
@@ -465,55 +466,56 @@ impl Area{
 			}
 		}
 	}
+	/// Retorna o valor da área concedida em megametros quadrados
 	pub fn to_square_megameters(&self) -> f64 {
 		if self.value > 1_000_000_000_000_000f64{
 			return self.value;
 		}
 		else {
 			if self.area_type == String::from("Square Micrometer"){
-				return self.value / 1_000_000.0;
+				return self.value / 1_000_000_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Millimeters"){
-				return self.value;
+				return self.value / 1_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Centimeters"){
-				return self.value * 100.0;
+				return self.value / 1_000_000_000_000_000_0.0;
 			}
 			else if self.area_type == String::from("Square Decimeters"){
-				return self.value * 1_000_0.0;
+				return self.value / 1_000_000_000_000_00.0;
 			}
 			else if self.area_type == String::from("Square Meters"){
-				return self.value * 1_000_000.0;
+				return self.value / 1_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Decameters"){
-				return self.value * 1_000_000_00.0;
+				return self.value / 1_000_000_000_0.0;
 			}
 			else if self.area_type == String::from("Square Hectometers"){
-				return self.value * 1_000_000_000_0.0;
+				return self.value / 1_000_000_00.0;
 			}
 			else if self.area_type == String::from("Square Kilometers"){
-				return self.value * 1_000_000_000_000.0;
+				return self.value / 1_000_000.0;
 			}
 			else if self.area_type == String::from("Square Megameters"){
-				return self.value * 1_000_000_000_000_00.0;
+				return self.value;
 			}
 			else if self.area_type == String::from("Square Gigameters"){
-				return self.value * 1_000_000_000_000_000_0.0;
+				return self.value * 1_000_000.0;
 			}
 			else if self.area_type == String::from("Square Terameters"){
-				return self.value * 1_000_000_000_000_000_000.0;
+				return self.value * 1_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Miles"){
-				return self.value * (2.59 * 1_000_000_000_000.0);
+				return self.value / 3_861_02.0;
 			}
 			else if self.area_type == String::from("Square Yards"){
-				return self.value * 836_127.0;
+				return self.value / (1.196 * 1_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Feet"){
-				return self.value * 92_903.0;
+				return self.value / (1.076 * 1_000_000_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Inches"){
-				return self.value * 645.16;
+				return self.value / (1.55 * 1_000_000_000_000_000.0);
 			}
 			else{
 				println!("Invalid area type");
@@ -521,55 +523,56 @@ impl Area{
 			}
 		}
 	}
+	/// Retorna o valor da área concedida em gigametros quadrados
 	pub fn to_square_gigameters(&self) -> f64 {
 		if self.value > 1_000_000_000_000_000f64{
 			return self.value;
 		}
 		else {
 			if self.area_type == String::from("Square Micrometer"){
-				return self.value / 1_000_000.0;
+				return self.value / 1_000_000_000_000_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Millimeters"){
-				return self.value;
+				return self.value / 1_000_000_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Centimeters"){
-				return self.value * 100.0;
+				return self.value / 1_000_000_000_000_000_000_000_0.0;
 			}
 			else if self.area_type == String::from("Square Decimeters"){
-				return self.value * 1_000_0.0;
+				return self.value / 1_000_000_000_000_000_000_00.0;
 			}
 			else if self.area_type == String::from("Square Meters"){
-				return self.value * 1_000_000.0;
+				return self.value / 1_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Decameters"){
-				return self.value * 1_000_000_00.0;
+				return self.value / 1_000_000_000_000_000_0.0;
 			}
 			else if self.area_type == String::from("Square Hectometers"){
-				return self.value * 1_000_000_000_0.0;
+				return self.value / 1_000_000_000_000_00.0;
 			}
 			else if self.area_type == String::from("Square Kilometers"){
-				return self.value * 1_000_000_000_000.0;
+				return self.value / 1_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Megameters"){
-				return self.value * 1_000_000_000_000_00.0;
+				return self.value / 1_000_000.0;
 			}
 			else if self.area_type == String::from("Square Gigameters"){
-				return self.value * 1_000_000_000_000_000_0.0;
+				return self.value;
 			}
 			else if self.area_type == String::from("Square Terameters"){
-				return self.value * 1_000_000_000_000_000_000.0;
+				return self.value * 1_000_000.0;
 			}
 			else if self.area_type == String::from("Square Miles"){
-				return self.value * (2.59 * 1_000_000_000_000.0);
+				return self.value / (3.861 * 1_000_000_000_00.0);
 			}
 			else if self.area_type == String::from("Square Yards"){
-				return self.value * 836_127.0;
+				return self.value / (1.196 * 1_000_000_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Feet"){
-				return self.value * 92_903.0;
+				return self.value / (1.076 * 1_000_000_000_000_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Inches"){
-				return self.value * 645.16;
+				return self.value / (1.55 * 1_000_000_000_000_000_000_000.0);
 			}
 			else{
 				println!("Invalid area type");
@@ -577,55 +580,56 @@ impl Area{
 			}
 		}
 	}
+	/// Retorna o valor da área concedida em terametros quadrados
 	pub fn to_square_terameters(&self) -> f64 {
 		if self.value > 1_000_000_000_000_000f64{
 			return self.value;
 		}
 		else {
 			if self.area_type == String::from("Square Micrometer"){
-				return self.value / 1_000_000.0;
+				return self.value / 1_000_000_000_000_000_000_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Millimeters"){
-				return self.value;
+				return self.value / 1_000_000_000_000_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Centimeters"){
-				return self.value * 100.0;
+				return self.value / 1_000_000_000_000_000_000_000_000_000_0.0;
 			}
 			else if self.area_type == String::from("Square Decimeters"){
-				return self.value * 1_000_0.0;
+				return self.value / 1_000_000_000_000_000_000_000_000_00.0;
 			}
 			else if self.area_type == String::from("Square Meters"){
-				return self.value * 1_000_000.0;
+				return self.value / 1_000_000_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Decameters"){
-				return self.value * 1_000_000_00.0;
+				return self.value / 1_000_000_000_000_000_000_000_0.0;
 			}
 			else if self.area_type == String::from("Square Hectometers"){
-				return self.value * 1_000_000_000_0.0;
+				return self.value / 1_000_000_000_000_000_000_00.0;
 			}
 			else if self.area_type == String::from("Square Kilometers"){
-				return self.value * 1_000_000_000_000.0;
+				return self.value / 1_000_000_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Megameters"){
-				return self.value * 1_000_000_000_000_00.0;
+				return self.value / 1_000_000_000_000.0;
 			}
 			else if self.area_type == String::from("Square Gigameters"){
-				return self.value * 1_000_000_000_000_000_0.0;
+				return self.value / 1_000_000.0;
 			}
 			else if self.area_type == String::from("Square Terameters"){
-				return self.value * 1_000_000_000_000_000_000.0;
+				return self.value;
 			}
 			else if self.area_type == String::from("Square Miles"){
-				return self.value * (2.59 * 1_000_000_000_000.0);
+				return self.value / (3.861 * 1_000_000_000_000_000_00.0);
 			}
 			else if self.area_type == String::from("Square Yards"){
-				return self.value * 836_127.0;
+				return self.value / (1.196 * 1_000_000_000_000_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Feet"){
-				return self.value * 92_903.0;
+				return self.value / (1.076 * 1_000_000_000_000_000_000_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Inches"){
-				return self.value * 645.16;
+				return self.value / (1.55 * 1_000_000_000_000_000_000_000_000_000.0);
 			}
 			else{
 				println!("Invalid area type");
@@ -633,55 +637,56 @@ impl Area{
 			}
 		}
 	}
+	/// Retorna o valor da área concedida em milhas quadradas
 	pub fn to_square_miles(&self) -> f64 {
 		if self.value > 1_000_000_000_000_000f64{
 			return self.value;
 		}
 		else {
 			if self.area_type == String::from("Square Micrometer"){
-				return self.value / 1_000_000.0;
+				return self.value / (2.59 * 1_000_000_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Millimeters"){
-				return self.value;
+				return self.value / (2.59 * 1_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Centimeters"){
-				return self.value * 100.0;
+				return self.value / (2.59 * 1_000_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Decimeters"){
-				return self.value * 1_000_0.0;
+				return self.value / (2.59 * 1_000_000_00.0);
 			}
 			else if self.area_type == String::from("Square Meters"){
-				return self.value * 1_000_000.0;
+				return self.value / (2.59 * 1_000_000.0);
 			}
 			else if self.area_type == String::from("Square Decameters"){
-				return self.value * 1_000_000_00.0;
+				return self.value / 25_900.0;
 			}
 			else if self.area_type == String::from("Square Hectometers"){
-				return self.value * 1_000_000_000_0.0;
+				return self.value / 259.0;
 			}
 			else if self.area_type == String::from("Square Kilometers"){
-				return self.value * 1_000_000_000_000.0;
+				return self.value / 2.59;
 			}
 			else if self.area_type == String::from("Square Megameters"){
-				return self.value * 1_000_000_000_000_00.0;
+				return self.value * 386_102.0;
 			}
 			else if self.area_type == String::from("Square Gigameters"){
-				return self.value * 1_000_000_000_000_000_0.0;
+				return self.value * (3.861 * 1_000_000_000_00.0);
 			}
 			else if self.area_type == String::from("Square Terameters"){
-				return self.value * 1_000_000_000_000_000_000.0;
+				return self.value * (3.861 * 1_000_000_000_000_000_00.0);
 			}
 			else if self.area_type == String::from("Square Miles"){
-				return self.value * (2.59 * 1_000_000_000_000.0);
+				return self.value;
 			}
 			else if self.area_type == String::from("Square Yards"){
-				return self.value * 836_127.0;
+				return self.value / (3.098 * 1_000_000.0);
 			}
 			else if self.area_type == String::from("Square Feet"){
-				return self.value * 92_903.0;
+				return self.value / (2.788 * 1_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Inches"){
-				return self.value * 645.16;
+				return self.value / (4.014 * 1_000_000_000.0);
 			}
 			else{
 				println!("Invalid area type");
@@ -689,55 +694,56 @@ impl Area{
 			}
 		}
 	}
+	/// Retorna o valor da área concedida em jardas quadradas
 	pub fn to_square_yards(&self) -> f64 {
 		if self.value > 1_000_000_000_000_000f64{
 			return self.value;
 		}
 		else {
 			if self.area_type == String::from("Square Micrometer"){
-				return self.value / 1_000_000.0;
+				return self.value / (8.361 * 1_000_000_000_00.0);
 			}
 			else if self.area_type == String::from("Square Millimeters"){
-				return self.value;
+				return self.value / (8.361 * 1_000_00.0);
 			}
 			else if self.area_type == String::from("Square Centimeters"){
-				return self.value * 100.0;
+				return self.value / 8361.0;
 			}
 			else if self.area_type == String::from("Square Decimeters"){
-				return self.value * 1_000_0.0;
+				return self.value / 83.613;
 			}
 			else if self.area_type == String::from("Square Meters"){
-				return self.value * 1_000_000.0;
+				return self.value * 1.196;
 			}
 			else if self.area_type == String::from("Square Decameters"){
-				return self.value * 1_000_000_00.0;
+				return self.value * 120.0;
 			}
 			else if self.area_type == String::from("Square Hectometers"){
-				return self.value * 1_000_000_000_0.0;
+				return self.value * 11_960.0;
 			}
 			else if self.area_type == String::from("Square Kilometers"){
-				return self.value * 1_000_000_000_000.0;
+				return self.value * (1.196 * 1_000_000.0);
 			}
 			else if self.area_type == String::from("Square Megameters"){
-				return self.value * 1_000_000_000_000_00.0;
+				return self.value * (1.196 * 1_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Gigameters"){
-				return self.value * 1_000_000_000_000_000_0.0;
+				return self.value * (1.196 * 1_000_000_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Terameters"){
-				return self.value * 1_000_000_000_000_000_000.0;
+				return self.value * (1.196 * 1_000_000_000_000_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Miles"){
-				return self.value * (2.59 * 1_000_000_000_000.0);
+				return self.value * (3.098 * 1_000_000.0);
 			}
 			else if self.area_type == String::from("Square Yards"){
-				return self.value * 836_127.0;
+				return self.value;
 			}
 			else if self.area_type == String::from("Square Feet"){
-				return self.value * 92_903.0;
+				return self.value / 9.0
 			}
 			else if self.area_type == String::from("Square Inches"){
-				return self.value * 645.16;
+				return self.value / 1296.0;
 			}
 			else{
 				println!("Invalid area type");
@@ -745,55 +751,56 @@ impl Area{
 			}
 		}
 	}
+	/// Retorna o valor da área concedida em pés quadrados
 	pub fn to_square_feet(&self) -> f64 {
 		if self.value > 1_000_000_000_000_000f64{
 			return self.value;
 		}
 		else {
 			if self.area_type == String::from("Square Micrometer"){
-				return self.value / 1_000_000.0;
+				return self.value / (9.29 * 1_000_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Millimeters"){
-				return self.value;
+				return self.value / 92903.0;
 			}
 			else if self.area_type == String::from("Square Centimeters"){
-				return self.value * 100.0;
+				return self.value / 929.0;
 			}
 			else if self.area_type == String::from("Square Decimeters"){
-				return self.value * 1_000_0.0;
+				return self.value / 93.0;
 			}
 			else if self.area_type == String::from("Square Meters"){
-				return self.value * 1_000_000.0;
+				return self.value * 10.764;
 			}
 			else if self.area_type == String::from("Square Decameters"){
-				return self.value * 1_000_000_00.0;
+				return self.value * 1076.0;
 			}
 			else if self.area_type == String::from("Square Hectometers"){
-				return self.value * 1_000_000_000_0.0;
+				return self.value * 1_076_39.0;
 			}
 			else if self.area_type == String::from("Square Kilometers"){
-				return self.value * 1_000_000_000_000.0;
+				return self.value * (1.076 * 1_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Megameters"){
-				return self.value * 1_000_000_000_000_00.0;
+				return self.value * (1.076 * 1_000_000_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Gigameters"){
-				return self.value * 1_000_000_000_000_000_0.0;
+				return self.value * (1.076 * 1_000_000_000_000_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Terameters"){
-				return self.value * 1_000_000_000_000_000_000.0;
+				return self.value * (1.076 * 1_000_000_000_000_000_000_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Miles"){
-				return self.value * (2.59 * 1_000_000_000_000.0);
+				return self.value * (2.788 * 1_000_000_0.0);
 			}
 			else if self.area_type == String::from("Square Yards"){
-				return self.value * 836_127.0;
+				return self.value * 9.0;
 			}
 			else if self.area_type == String::from("Square Feet"){
-				return self.value * 92_903.0;
+				return self.value;
 			}
 			else if self.area_type == String::from("Square Inches"){
-				return self.value * 645.16;
+				return self.value / 144.0;
 			}
 			else{
 				println!("Invalid area type");
@@ -801,55 +808,56 @@ impl Area{
 			}
 		}
 	}
+	/// Retorna o valor da área concedida em polegadas quadradas
 	pub fn to_square_inches(&self) -> f64 {
 		if self.value > 1_000_000_000_000_000f64{
 			return self.value;
 		}
 		else {
 			if self.area_type == String::from("Square Micrometer"){
-				return self.value / 1_000_000.0;
+				return self.value / (6.452 * 1_000_000_00.0);
 			}
 			else if self.area_type == String::from("Square Millimeters"){
-				return self.value;
+				return self.value / 645.2;
 			}
 			else if self.area_type == String::from("Square Centimeters"){
-				return self.value * 100.0;
+				return self.value / 6.452;
 			}
 			else if self.area_type == String::from("Square Decimeters"){
-				return self.value * 1_000_0.0;
+				return self.value * 15.5;
 			}
 			else if self.area_type == String::from("Square Meters"){
-				return self.value * 1_000_000.0;
+				return self.value * 1550.0;
 			}
 			else if self.area_type == String::from("Square Decameters"){
-				return self.value * 1_000_000_00.0;
+				return self.value * 1_550_00.0;
 			}
 			else if self.area_type == String::from("Square Hectometers"){
-				return self.value * 1_000_000_000_0.0;
+				return self.value * 1_550_000_000_00.0;
 			}
 			else if self.area_type == String::from("Square Kilometers"){
-				return self.value * 1_000_000_000_000.0;
+				return self.value * (1.55 * 1_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Megameters"){
-				return self.value * 1_000_000_000_000_00.0;
+				return self.value * (1.55 * 1_000_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Gigameters"){
-				return self.value * 1_000_000_000_000_000_0.0;
+				return self.value * (1.55 * 1_000_000_000_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Terameters"){
-				return self.value * 1_000_000_000_000_000_000.0;
+				return self.value * (1.55 * 1_000_000_000_000_000_000_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Miles"){
-				return self.value * (2.59 * 1_000_000_000_000.0);
+				return self.value * (4.014 * 1_000_000_000.0);
 			}
 			else if self.area_type == String::from("Square Yards"){
-				return self.value * 836_127.0;
+				return self.value * 1296.0;
 			}
 			else if self.area_type == String::from("Square Feet"){
-				return self.value * 92_903.0;
+				return self.value * 144.0;
 			}
 			else if self.area_type == String::from("Square Inches"){
-				return self.value * 645.16;
+				return self.value;
 			}
 			else{
 				println!("Invalid area type");
